@@ -1,11 +1,26 @@
+# Copyright 2010 New Relic, Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import threading
-import warnings
 
 import newrelic.core.config
 import newrelic.core.agent
+import newrelic.api.import_hook
 
 import newrelic.packages.six as six
 
+
 class Application(object):
 
     _lock = threading.Lock()
@@ -83,7 +98,8 @@ class Application(object):
         # configuration will later be used. Note that the timeout only
         # applies on the first call to activate the application.
 
-        self._agent.activate_application(self._name, self._linked, timeout)
+        self._agent.activate_application(self._name, self._linked, timeout,
+                newrelic.api.import_hook._uninstrumented_modules)
 
     def shutdown(self):
         pass
@@ -108,47 +124,40 @@ class Application(object):
         if self.active:
             self._agent.record_custom_metric(self._name, name, value)
 
-    def record_metric(self, name, value):
-        warnings.warn('Internal API change. Use record_custom_metric() '
-                'instead of record_metric().', DeprecationWarning,
-                stacklevel=2)
-
-        return self.record_custom_metric(name, value)
-
     def record_custom_metrics(self, metrics):
         if self.active and metrics:
             self._agent.record_custom_metrics(self._name, metrics)
 
-    def record_metrics(self, metrics):
-        warnings.warn('Internal API change. Use record_custom_metrics() '
-                'instead of record_metrics().', DeprecationWarning,
-                stacklevel=2)
-
-        return self.record_custom_metrics(metrics)
-
-    def record_transaction(self, data, profile_samples=None):
+    def record_custom_event(self, event_type, params):
         if self.active:
-            self._agent.record_transaction(self._name, data, profile_samples)
+            self._agent.record_custom_event(self._name, event_type, params)
+
+    def record_transaction(self, data):
+        if self.active:
+            self._agent.record_transaction(self._name, data)
 
     def normalize_name(self, name, rule_type='url'):
         if self.active:
             return self._agent.normalize_name(self._name, name, rule_type)
         return name, False
 
+    def compute_sampled(self):
+        if not self.active or not self.settings.distributed_tracing.enabled:
+            return False
+
+        return self._agent.compute_sampled(self._name)
+
+
 def application_instance(name=None):
     return Application._instance(name)
 
-def application():
-   warnings.warn('Internal API change. Use application_instance() '
-           'instead of application().', DeprecationWarning, stacklevel=2)
-
-   return application_instance()
 
 def register_application(name=None, timeout=None):
     instance = application_instance(name)
     instance.activate(timeout)
     return instance
 
+
 def application_settings(name=None):
     instance = application_instance(name)
     return instance.settings
