@@ -1,19 +1,32 @@
-import sys
-import types
-import time
+# Copyright 2010 New Relic, Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 
 import newrelic.core.solr_node
 
-import newrelic.api.transaction
 import newrelic.api.time_trace
 import newrelic.api.object_wrapper
 
+
 class SolrTrace(newrelic.api.time_trace.TimeTrace):
 
-    node = newrelic.core.solr_node.SolrNode
-
-    def __init__(self, transaction, library, command):
-        super(SolrTrace, self).__init__(transaction)
+    def __init__(self, library, command, **kwargs):
+        parent = None
+        if kwargs:
+            if len(kwargs) > 1:
+                raise TypeError("Invalid keyword arguments:", kwargs)
+            parent = kwargs['parent']
+        super(SolrTrace, self).__init__(parent)
 
         self.library = library
         self.command = command
@@ -22,15 +35,23 @@ class SolrTrace(newrelic.api.time_trace.TimeTrace):
         return '<%s %s>' % (self.__class__.__name__, dict(
                 library=self.library, command=self.command))
 
-    def create_node(self):
-        return self.node(library=self.library, command=self.command,
-                children=self.children, start_time=self.start_time,
-                end_time=self.end_time, duration=self.duration,
-                exclusive=self.exclusive)
-
     def terminal_node(self):
         return True
 
+    def create_node(self):
+        return newrelic.core.solr_node.SolrNode(
+                library=self.library,
+                command=self.command,
+                children=self.children,
+                start_time=self.start_time,
+                end_time=self.end_time,
+                duration=self.duration,
+                exclusive=self.exclusive,
+                guid=self.guid,
+                agent_attributes=self.agent_attributes,
+                user_attributes=self.user_attributes,)
+
+
 class SolrTraceWrapper(object):
 
     def __init__(self, wrapped, library, command):
@@ -58,8 +79,8 @@ class SolrTraceWrapper(object):
                               self._nr_command)
 
     def __call__(self, *args, **kwargs):
-        transaction = newrelic.api.transaction.current_transaction()
-        if not transaction:
+        parent = newrelic.api.time_trace.current_trace()
+        if not parent:
             return self._nr_next_object(*args, **kwargs)
 
         if callable(self._nr_library):
@@ -80,14 +101,16 @@ class SolrTraceWrapper(object):
         else:
             command = self._nr_command
 
-        with SolrTrace(transaction, library, command):
+        with SolrTrace(library, command, parent=parent):
             return self._nr_next_object(*args, **kwargs)
 
+
 def solr_trace(library, command):
     def decorator(wrapped):
         return SolrTraceWrapper(wrapped, library, command)
     return decorator
 
+
 def wrap_solr_trace(module, object_path, library, command):
     newrelic.api.object_wrapper.wrap_object(module, object_path,
             SolrTraceWrapper, (library, command))
