@@ -1,9 +1,22 @@
+# Copyright 2010 New Relic, Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 from __future__ import print_function
 
 import os
 import sys
 import time
-import warnings
 import zlib
 from pprint import pprint
 
@@ -426,25 +439,22 @@ class HttpClient(BaseClient):
         if body and len(body) > self._max_payload_size_in_bytes:
             return 413, b""
 
-        with warnings.catch_warnings():
-            warnings.simplefilter("ignore")
-
-            try:
-                response = self._connection.request_encode_url(
-                    method,
-                    path,
-                    fields=params,
-                    body=body,
-                    headers=merged_headers,
-                    **self._urlopen_kwargs
-                )
-            except urllib3.exceptions.HTTPError as e:
-                self.log_response(
-                    self._audit_log_fp, request_id, 0, None, None, connection,
-                )
-                # All urllib3 HTTP errors should be treated as a network
-                # interface exception.
-                raise NetworkInterfaceException(e)
+        try:
+            response = self._connection.request_encode_url(
+                method,
+                path,
+                fields=params,
+                body=body,
+                headers=merged_headers,
+                **self._urlopen_kwargs
+            )
+        except urllib3.exceptions.HTTPError as e:
+            self.log_response(
+                self._audit_log_fp, request_id, 0, None, None, connection,
+            )
+            # All urllib3 HTTP errors should be treated as a network
+            # interface exception.
+            raise NetworkInterfaceException(e)
 
         self.log_response(
             self._audit_log_fp,
