@@ -1,13 +1,29 @@
+# Copyright 2010 New Relic, Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 """This module implements functions for querying properties of the operating
 system or for the specific process the code is running in.
 
 """
 
+import logging
 import os
-import sys
 import re
-import multiprocessing
+import socket
 import subprocess
+import sys
+import threading
 
 try:
     from subprocess import check_output as _execute_program
@@ -35,10 +51,14 @@ try:
 except ImportError:
     pass
 
+_logger = logging.getLogger(__name__)
+
+
 def logical_processor_count():
     """Returns the number of logical processors in the system.
 
     """
+    import multiprocessing
 
     # The multiprocessing module provides support for Windows,
     # BSD systems (including MacOS X) and systems which support
@@ -70,7 +90,7 @@ def logical_processor_count():
 
         res = 0
         for pd in pseudoDevices:
-            if expr.match(pd) != None:
+            if expr.match(pd) is not None:
                 res += 1
 
         if res > 0:
@@ -82,6 +102,7 @@ def logical_processor_count():
 
     return 1
 
+
 def _linux_physical_processor_count(filename=None):
     # For Linux we can use information from '/proc/cpuinfo.
 
@@ -156,6 +177,7 @@ def _linux_physical_processor_count(filename=None):
 
     return (num_physical_processors, num_physical_cores)
 
+
 def _darwin_physical_processor_count():
     # For MacOS X we can use sysctl.
 
@@ -177,6 +199,7 @@ def _darwin_physical_processor_count():
 
     return (num_physical_processors, num_physical_cores)
 
+
 def physical_processor_count():
     """Returns the number of physical processors and the number of physical
     cores in the system as a tuple. One or both values may be None, if a value
@@ -191,10 +214,11 @@ def physical_processor_count():
 
     return (None, None)
 
+
 def _linux_total_physical_memory(filename=None):
     # For Linux we can use information from /proc/meminfo. Although the
     # units is given in the file, it is always in kilobytes so we do not
-    # need to accomodate any other unit types beside 'kB'.
+    # need to accommodate any other unit types beside 'kB'.
 
     filename = filename or '/proc/meminfo'
 
@@ -209,11 +233,12 @@ def _linux_total_physical_memory(filename=None):
                 key, value = match.groups(['key', 'value'])
                 if key == 'MemTotal':
                     memory_bytes = float(value) * 1024
-                    return memory_bytes / (1024*1024)
+                    return memory_bytes / (1024 * 1024)
 
     except Exception:
         pass
 
+
 def _darwin_total_physical_memory():
     # For MacOS X we can use sysctl. The value queried from sysctl is
     # always bytes.
@@ -222,12 +247,13 @@ def _darwin_total_physical_memory():
 
     try:
         return float(_execute_program(command,
-                stderr=subprocess.PIPE)) / (1024*1024)
+                stderr=subprocess.PIPE)) / (1024 * 1024)
     except subprocess.CalledProcessError:
         pass
     except ValueError:
         pass
 
+
 def total_physical_memory():
     """Returns the total physical memory available in the system. Returns
     None if the value cannot be calculated.
@@ -239,6 +265,7 @@ def total_physical_memory():
     elif sys.platform == 'darwin':
         return _darwin_total_physical_memory()
 
+
 def _linux_physical_memory_used(filename=None):
     # For Linux we can use information from the proc filesystem. We use
     # '/proc/statm' as it easier to parse than '/proc/status' file. The
@@ -264,11 +291,12 @@ def _linux_physical_memory_used(filename=None):
         with open(filename, 'r') as fp:
             rss_pages = float(fp.read().split()[1])
             memory_bytes = rss_pages * resource.getpagesize()
-            return memory_bytes / (1024*1024)
+            return memory_bytes / (1024 * 1024)
 
     except Exception:
         return 0
 
+
 def physical_memory_used():
     """Returns the amount of physical memory used in MBs. Returns 0 if
     the value cannot be calculated.
@@ -297,10 +325,89 @@ def physical_memory_used():
             # value is in kilobytes, it is actually in bytes.
 
             memory_bytes = float(rusage.ru_maxrss)
-            return memory_bytes / (1024*1024)
+            return memory_bytes / (1024 * 1024)
 
         elif rusage.ru_maxrss > 0:
             memory_kbytes = float(rusage.ru_maxrss)
             return memory_kbytes / 1024
 
     return 0
+
+
+def _resolve_hostname(use_dyno_names, dyno_shorten_prefixes):
+    dyno_name = os.environ.get('DYNO')
+    if not use_dyno_names or not dyno_name:
+        return socket.gethostname()
+
+    for prefix in dyno_shorten_prefixes:
+        if prefix and dyno_name.startswith(prefix):
+            return '%s.*' % prefix
+
+    return dyno_name
+
+
+_nr_cached_hostname_lock = threading.Lock()
+_nr_cached_ipaddress_lock = threading.Lock()
+
+_nr_cached_hostname = None
+_nr_cached_ip_address = None
+
+
+def gethostname(use_dyno_names=False, dyno_shorten_prefixes=()):
+    """Cache the output of socket.gethostname().
+
+    Keeps the reported hostname consistent throughout an agent run.
+
+    """
+
+    global _nr_cached_hostname
+    global _nr_cached_hostname_lock
+
+    if _nr_cached_hostname:
+        return _nr_cached_hostname
+
+    # Only lock for the one-time write.
+
+    with _nr_cached_hostname_lock:
+        if _nr_cached_hostname is None:
+            _nr_cached_hostname = _resolve_hostname(use_dyno_names,
+                    dyno_shorten_prefixes)
+
+    return _nr_cached_hostname
+
+
+def getips():
+    """Cache the output of socket.getsockname().
+
+    Keeps the reported ips consistent throughout an agent run.
+
+    """
+
+    global _nr_cached_ip_address
+    global _nr_cached_ipaddress_lock
+
+    if _nr_cached_ip_address is not None:
+        return _nr_cached_ip_address
+
+    # Only lock for the one-time write.
+
+    with _nr_cached_ipaddress_lock:
+        if _nr_cached_ip_address is None:
+            _nr_cached_ip_address = []
+
+            try:
+                # connect with UDP doesn't send packets (i.e. there's no
+                # handshake like with TCP)
+                s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
+            except Exception:
+                return _nr_cached_ip_address
+
+            try:
+                s.connect(('1.1.1.1', 1))
+                _nr_cached_ip_address.append(s.getsockname()[0])
+            except Exception:
+                pass
+            finally:
+                s.close()
+
+    return _nr_cached_ip_address
