@@ -1,3 +1,17 @@
+# Copyright 2010 New Relic, Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import logging
 import os
 
@@ -13,6 +27,7 @@ from newrelic.common.encoding_utils import (
 from newrelic.common.utilization import (
     AWSUtilization,
     AzureUtilization,
+    BootIdUtilization,
     DockerUtilization,
     GCPUtilization,
     KubernetesUtilization,
@@ -288,7 +303,7 @@ class AgentProtocol(object):
         if ip_address:
             utilization_settings["ip_address"] = ip_address
 
-        boot_id = system_info.BootIdUtilization.detect()
+        boot_id = BootIdUtilization.detect()
         if boot_id:
             utilization_settings["boot_id"] = boot_id
 
