@@ -1,6 +1,26 @@
-from newrelic.agent import (application as default_application,
-        wrap_function_wrapper, BackgroundTask, FunctionTrace, FunctionWrapper,
-        current_transaction, callable_name, ExternalTrace, wrap_function_trace)
+# Copyright 2010 New Relic, Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+from newrelic.api.application import application_instance as default_application
+from newrelic.common.object_wrapper import (wrap_function_wrapper,
+        FunctionWrapper)
+from newrelic.api.background_task import BackgroundTask
+from newrelic.api.function_trace import FunctionTrace, wrap_function_trace
+from newrelic.api.transaction import current_transaction
+from newrelic.api.time_trace import current_trace
+from newrelic.common.object_names import callable_name
+from newrelic.api.external_trace import ExternalTrace
 
 # Following wrappers are specifically for a gearman client.
 
@@ -20,11 +40,6 @@ def wrapper_GearmanConnectionManager_poll_connections_until_stopped(
     def _bind_params(submitted_connections, *args, **kwargs):
         return submitted_connections
 
-    transaction = current_transaction()
-
-    if transaction is None:
-        return wrapped(*args, **kwargs)
-
     # Because gearman uses a custom message based protocol over a raw
     # socket, we can't readily wrap a single function which is
     # performing a request and then returning a response. The best we
@@ -57,7 +72,7 @@ def wrapper_GearmanConnectionManager_poll_connections_until_stopped(
     url = 'gearman://%s:%s' % (first_connection.gearman_host,
             first_connection.gearman_port)
 
-    with ExternalTrace(transaction, 'gearman', url):
+    with ExternalTrace('gearman', url):
         return wrapped(*args, **kwargs)
 
 def wrapper_GearmanConnectionManager_handle_function(wrapped, instance,
@@ -71,7 +86,7 @@ def wrapper_GearmanConnectionManager_handle_function(wrapped, instance,
     if transaction is None:
         return wrapped(*args, **kwargs)
 
-    tracer = transaction.active_node()
+    tracer = current_trace()
 
     if not isinstance(tracer, ExternalTrace):
         return wrapped(*args, **kwargs)
@@ -80,7 +95,7 @@ def wrapper_GearmanConnectionManager_handle_function(wrapped, instance,
     # ended up communicating with. This could get overridden multiple
     # times in the context of a single poll_connections_until_stopped()
     # call and so will be set to the last server data was processed for.
-    # This thus may not necessarily be correct if commnicating with
+    # This thus may not necessarily be correct if communicating with
     # multiple servers and data from more than one was being handled for
     # some reason. Can't really do much better than this though but will
     # be fine for the expected typical use case of a single server.
@@ -137,11 +152,11 @@ def wrapper_callback_function(wrapped, instance, args, kwargs):
     # dispatch code and do not actually propagate up to the level of the
     # background task wrapper.
 
-    with FunctionTrace(transaction, callable_name(wrapped)):
+    with FunctionTrace(callable_name(wrapped)) as trace:
         try:
             return wrapped(*args, **kwargs)
         except:  # Catch all
-            transaction.record_exception()
+            trace.record_exception()
             raise
 
 def wrapper_GearmanWorker_register_task(wrapped, instance, args, kwargs):
