@@ -1,4 +1,16 @@
-import types
+# Copyright 2010 New Relic, Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 
 import newrelic.packages.six as six
 
@@ -7,6 +19,7 @@ import newrelic.api.function_trace
 import newrelic.api.object_wrapper
 import newrelic.api.in_function
 
+
 class MethodWrapper(object):
 
     def __init__(self, wrapped, priority=None):
@@ -29,11 +42,12 @@ class MethodWrapper(object):
             transaction.set_transaction_name(self._nr_name,
                     priority=self._nr_priority)
             with newrelic.api.function_trace.FunctionTrace(
-                    transaction, name=self._nr_name):
+                    name=self._nr_name):
                 return self._nr_wrapped(*args, **kwargs)
         else:
             return self._nr_wrapped(*args, **kwargs)
 
+
 class ResourceInitWrapper(object):
 
     def __init__(self, wrapped):
@@ -61,11 +75,13 @@ class ResourceInitWrapper(object):
                 setattr(handler, name, MethodWrapper(
                         getattr(handler, name), priority=6))
 
+
 def instrument_piston_resource(module):
 
     newrelic.api.object_wrapper.wrap_object(module,
             'Resource.__init__', ResourceInitWrapper)
 
+
 def instrument_piston_doc(module):
 
     def in_HandlerMethod_init(self, method, *args, **kwargs):
