@@ -1,13 +1,32 @@
+# Copyright 2010 New Relic, Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 """Instrumentation module for Bottle framework.
 
 """
 
 import functools
 
-from newrelic.agent import (wrap_function_trace, wrap_out_function,
-    wrap_wsgi_application, function_wrapper, current_transaction,
-    FunctionTrace, callable_name, ignore_status_code, ObjectProxy,
-    FunctionTraceWrapper, wrap_object_attribute, wrap_function_wrapper)
+from newrelic.api.function_trace import (FunctionTrace, FunctionTraceWrapper,
+        wrap_function_trace)
+from newrelic.api.transaction import current_transaction
+from newrelic.api.wsgi_application import wrap_wsgi_application
+from newrelic.common.object_names import callable_name
+from newrelic.common.object_wrapper import (wrap_out_function,
+        function_wrapper, ObjectProxy, wrap_object_attribute,
+        wrap_function_wrapper)
+from newrelic.core.config import ignore_status_code
 
 module_bottle = None
 
@@ -45,7 +64,7 @@ def callback_wrapper(wrapped, instance, args, kwargs):
 
     transaction.set_transaction_name(name, priority=2)
 
-    with FunctionTrace(transaction, name):
+    with FunctionTrace(name) as trace:
         try:
             return wrapped(*args, **kwargs)
 
@@ -56,8 +75,7 @@ def callback_wrapper(wrapped, instance, args, kwargs):
             # return it instead. This doesn't always seem to be the case
             # though when plugins are used, although that may depend on
             # the specific bottle version being used.
-
-            transaction.record_exception(ignore_errors=should_ignore)
+            trace.record_exception(ignore_errors=should_ignore)
             raise
 
 def output_wrapper_Bottle_match(result):
