@@ -1,15 +1,31 @@
+# Copyright 2010 New Relic, Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import sys
 import os
 
 import newrelic.api.transaction
 import newrelic.api.import_hook
-import newrelic.api.web_transaction
+import newrelic.api.wsgi_application
 import newrelic.api.external_trace
 import newrelic.api.function_trace
-import newrelic.api.name_transaction
+import newrelic.api.transaction_name
 import newrelic.api.object_wrapper
 import newrelic.api.pre_function
 
+from newrelic.api.time_trace import record_exception
+
 def instrument_gluon_compileapp(module):
 
     # Wrap the run_models_in() function as first phase
@@ -18,12 +34,12 @@ def instrument_gluon_compileapp(module):
     # transaction is combination of the application name
     # and view path.
 
-    def name_transaction_run_models_in(environment):
+    def transaction_name_run_models_in(environment):
         return '%s::%s' % (environment['request'].application,
                 environment['response'].view)
 
-    newrelic.api.name_transaction.wrap_name_transaction(module,
-            'run_models_in', name=name_transaction_run_models_in,
+    newrelic.api.transaction_name.wrap_transaction_name(module,
+            'run_models_in', name=transaction_name_run_models_in,
             group='Web2Py')
 
     # Wrap functions which coordinate the execution of
@@ -83,7 +99,7 @@ def instrument_gluon_restricted(module):
 
 def instrument_gluon_main(module):
 
-    newrelic.api.web_transaction.wrap_wsgi_application(module, 'wsgibase')
+    newrelic.api.wsgi_application.wrap_wsgi_application(module, 'wsgibase')
 
     # Wrap main function which dispatches the various
     # phases of a request in order to capture any
@@ -109,7 +125,7 @@ def instrument_gluon_main(module):
                 except HTTP:
                     raise
                 except:  # Catch all
-                    txn.record_exception(*sys.exc_info())
+                    record_exception()
                     raise
             else:
                 return self._nr_next_object(request, response, session)
@@ -185,7 +201,7 @@ def instrument_gluon_http(module):
     # fact that arbitrary rewrite rules can be used may
     # mean that isn't always the case.
 
-    def name_transaction_name_not_found(response, *args, **kwargs):
+    def transaction_name_name_not_found(response, *args, **kwargs):
         txn = newrelic.api.transaction.current_transaction()
         if not txn:
             return
@@ -202,11 +218,11 @@ def instrument_gluon_http(module):
             return
 
         if response.status == 400:
-            txn.name_transaction('400', 'Uri')
+            txn.set_transaction_name('400', 'Uri')
             return
 
         if response.status == 404:
-            txn.name_transaction('404', 'Uri')
+            txn.set_transaction_name('404', 'Uri')
             return
 
         if 'static_file' not in frame.f_locals:
@@ -221,19 +237,19 @@ def instrument_gluon_http(module):
                     parts = os.path.split(path_info)
                     if parts[1] == '':
                         if parts[0] == '/':
-                            txn.name_transaction('*', 'Web2Py')
+                            txn.set_transaction_name('*', 'Web2Py')
                         else:
                             name = '%s/*' % parts[0].lstrip('/')
-                            txn.name_transaction(name, 'Web2Py')
+                            txn.set_transaction_name(name, 'Web2Py')
                     else:
                         extension = os.path.splitext(parts[1])[-1]
                         name = '%s/*%s' % (parts[0].lstrip('/'), extension)
-                        txn.name_transaction(name, 'Web2Py')
+                        txn.set_transaction_name(name, 'Web2Py')
                 else:
-                    txn.name_transaction('*', 'Web2Py')
+                    txn.set_transaction_name('*', 'Web2Py')
 
             else:
-                txn.name_transaction('*', 'Web2Py')
+                txn.set_transaction_name('*', 'Web2Py')
 
     newrelic.api.pre_function.wrap_pre_function(
-            module, 'HTTP.to', name_transaction_name_not_found)
+            module, 'HTTP.to', transaction_name_name_not_found)
